pub struct ParserGuest {}Expand description
Auto-generated bindings for an instance a component which
implements the world parser-guest.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
ParserGuest::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
ParserGuestPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesParserGuestPre::instantiateto create aParserGuest. -
If you’ve instantiated the instance yourself already then you can use
ParserGuest::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl ParserGuest
impl ParserGuest
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ParserGuest>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<ParserGuest>
Convenience wrapper around ParserGuestPre::new and
ParserGuestPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<ParserGuest>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<ParserGuest>
Convenience wrapper around ParserGuestIndices::new and
ParserGuestIndices::load.
pub fn add_to_linker<T, U>( linker: &mut Linker<T>, get: impl Fn(&mut T) -> &mut U + Send + Sync + Copy + 'static, ) -> Result<()>