pub struct ParserGuestIndices {}Expand description
Auto-generated bindings for index of the exports of
parser-guest.
This is an implementation detail of ParserGuestPre and can
be constructed if needed as well.
For more information see ParserGuest as well.
Implementations
Sourceimpl ParserGuestIndices
impl ParserGuestIndices
Sourcepub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
Creates a new copy of ParserGuestIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn load(
&self,
store: impl AsContextMut,
instance: &Instance,
) -> Result<ParserGuest>
pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<ParserGuest>
Uses the indices stored in self to load an instance
of ParserGuest from the instance provided.
Note that at this time this method will additionally perform type-checks of all exports.